@@ -16,4 +16,4 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-from dmol3parser.Dmol3Parser import Dmol3Parser
\ No newline at end of file
+from .dmol3_parser import Dmol3Parser
