@@ -16,4 +16,4 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-from .GROMOSParser import GromacsParserInterface as GromosParser
\ No newline at end of file
+from .gromos_parser import GromosParser
