@@ -1,8 +1,7 @@
 #
 # Copyright The NOMAD Authors.
 #
-# This file is part of NOMAD.
-# See https://nomad-lab.eu for further info.
+# This file is part of NOMAD. See https://nomad-lab.eu for further info.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,9 +18,15 @@
 
 import sys
 import json
+import logging
 
+from nomad.utils import configure_logging
+from nomad.datamodel import EntryArchive
 from lammpsparser import LammpsParser
 
+
 if __name__ == "__main__":
-    archive = LammpsParser.main(sys.argv[1])
+    configure_logging(console_log_level=logging.DEBUG)
+    archive = EntryArchive()
+    LammpsParser().parse(sys.argv[1], archive, logging)
     json.dump(archive.m_to_dict(), sys.stdout, indent=2)
