@@ -16,4 +16,4 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-from .parser_mopac import MopacParser
\ No newline at end of file
+from .mopac_parser import MopacParser
