@@ -16,4 +16,4 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-from qboxparser.QboxParser import QboxParser
\ No newline at end of file
+from .qbox_parser import QboxParser
