@@ -33,25 +33,25 @@ from typing import List
 import os
 import numpy as np
 import logging
-import pint
 from datetime import datetime
 import ase
 import re
 from xml.sax import ContentHandler, make_parser  # type: ignore
 
 from .metainfo import m_env
+from nomad.units import ureg
 from nomad.parsing import FairdiParser
 from nomad.parsing.file_parser import FileParser
 from nomad.parsing.file_parser.text_parser import TextParser, Quantity
 from nomad.datamodel.metainfo.common_dft import Run, Method, XCFunctionals,\
     SingleConfigurationCalculation, ScfIteration, MethodAtomKind, System, Eigenvalues,\
-    KBand, KBandSegment, Dos, BasisSetCellDependent, MethodBasisSet
+    KBand, KBandSegment, Dos, BasisSetCellDependent, MethodBasisSet, SamplingMethod
 
 
 def get_key_values(val_in):
     val = [v for v in val_in.split('\n') if '=' in v]
     data = {}
-    pattern = re.compile(r'([A-Z]+)\s*=\s*([\w\-]+\s{0,3}[\d\. ]*)')
+    pattern = re.compile(r'([A-Z_]+)\s*=\s*([\w\-]+\s{0,3}[\d\. ]*[E\-\d]*)')
 
     def convert(v):
         if isinstance(v, list):
@@ -162,6 +162,9 @@ class ContentParser:
             val = -1 if self.incar.get('NSW', 0) in [0, 1] else 0
         return val
 
+    def is_converged(self, n_calc):
+        return
+
 
 class OutcarTextParser(TextParser):
     def __init__(self):
@@ -170,8 +173,6 @@ class OutcarTextParser(TextParser):
         super().__init__(None)
 
     def init_quantities(self):
-        self._quantities = []
-
         def str_to_array(val_in):
             val = [re.findall(r'(\-?\d+\.[\dEe]+)', v) for v in val_in.strip().split('\n') if '--' not in v]
             return np.array([v[0:3] for v in val], float), np.array([v[3:6] for v in val], float)
@@ -194,6 +195,15 @@ class OutcarTextParser(TextParser):
             date = date.replace('.', ' ')
             return dict(version=version, subversion=subversion, platform=platform, date=date, time=time)
 
+        def str_to_positions(val_in):
+            re_position = re.compile(r'\d*\s*(\-*\d+\.\d+)\s*(\-*\d+\.\d+)\s*(\-*\d+\.\d+)')
+            positions = []
+            for val in val_in.strip().split('\n'):
+                position = re_position.search(val)
+                if position:
+                    positions.append(position.groups())
+            return np.array(positions, dtype=float)
+
         scf_iteration = [
             Quantity(
                 'energy_total', r'free energy\s*TOTEN\s*=\s*([\d\.\-]+)\s*eV',
@@ -210,87 +220,100 @@ class OutcarTextParser(TextParser):
                 str_operation=get_key_values, convert=False)
         ]
 
-        self._quantities.append(Quantity(
-            'calculation',
-            r'(\-\-\s*Iteration\s*\d+\(\s*\d+\s*\)\s*[\s\S]+?(?:FREE ENERGIE OF THE ION\-ELECTRON SYSTEM \(eV\)))'
-            r'([\s\S]+?\-{100})',
-            repeats=True, sub_parser=TextParser(quantities=[
-                Quantity(
-                    'scf_iteration',
-                    r'Iteration\s*\d+\(\s*\d+\s*\)([\s\S]+?energy\(sigma\->0\)\s*=\s*.+)',
-                    repeats=True, sub_parser=TextParser(quantities=scf_iteration)),
-                Quantity(
-                    'energies',
-                    r'FREE ENERGIE OF THE ION-ELECTRON SYSTEM \(eV\)\s*\-+\s*([\s\S]+?)\-{10}',
-                    sub_parser=TextParser(quantities=[
-                        Quantity(
-                            'energy_total',
-                            r'free\s*energy\s*TOTEN\s*=\s*([\-\d\.]+)',
-                            repeats=False, dtype=float),
-                        Quantity(
-                            'energy_entropy0',
-                            r'energy\s*without\s*entropy\s*=\s*([\-\d\.]+)',
-                            repeats=False, dtype=float),
-                        Quantity(
-                            'energy_T0',
-                            r'energy\(sigma\->0\)\s*=\s*([\-\d\.]+)',
-                            repeats=False, dtype=float)])),
-                Quantity(
-                    'stress',
-                    r'in kB\s*(\-?\d+\.\d+)\s*(\-?\d+\.\d+)\s*(\-?\d+\.\d+)\s*'
-                    r'(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)',
-                    str_operation=str_to_stress, convert=False),
-                Quantity(
-                    'positions_forces',
-                    r'POSITION\s*TOTAL\-FORCE \(eV/Angst\)\s*\-+\s*([\d\.\s\-E]+)',
-                    str_operation=str_to_array, convert=False),
-                Quantity(
-                    'lattice_vectors',
-                    r'direct lattice vectors\s*reciprocal lattice vectors\s*'
-                    r'(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)'
-                    r'(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)'
-                    r'(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)',
-                    str_operation=str_to_array, convert=False),
-                Quantity(
-                    'converged',
-                    r'aborting loop because (EDIFF is reached)', repeats=False,
-                    dtype=str, convert=False),
-                Quantity(
-                    'fermi_energy', r'E\-fermi :\s*([\d\.]+)', dtype=str, repeats=False),
-                Quantity(
-                    'eigenvalues',
-                    r'band No\.\s*band energies\s*occupation\s*([\d\.\s\-]+?)(?:k\-point|spin|\-{10})',
-                    repeats=True, dtype=float)
-            ])))
+        calculation_quantities = [
+            Quantity(
+                'scf_iteration',
+                r'Iteration\s*\d+\(\s*\d+\s*\)([\s\S]+?energy\(sigma\->0\)\s*=\s*.+)',
+                repeats=True, sub_parser=TextParser(quantities=scf_iteration)),
+            Quantity(
+                'energies',
+                r'FREE ENERGIE OF THE ION-ELECTRON SYSTEM \(eV\)\s*\-+\s*([\s\S]+?)\-{10}',
+                sub_parser=TextParser(quantities=[
+                    Quantity(
+                        'energy_total',
+                        r'free\s*energy\s*TOTEN\s*=\s*([\-\d\.]+)',
+                        repeats=False, dtype=float),
+                    Quantity(
+                        'energy_entropy0',
+                        r'energy\s*without\s*entropy\s*=\s*([\-\d\.]+)',
+                        repeats=False, dtype=float),
+                    Quantity(
+                        'energy_T0',
+                        r'energy\(sigma\->0\)\s*=\s*([\-\d\.]+)',
+                        repeats=False, dtype=float)])),
+            Quantity(
+                'stress',
+                r'in kB\s*(\-?\d+\.\d+)\s*(\-?\d+\.\d+)\s*(\-?\d+\.\d+)\s*'
+                r'(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)',
+                str_operation=str_to_stress, convert=False),
+            Quantity(
+                'positions_forces',
+                r'POSITION\s*TOTAL\-FORCE \(eV/Angst\)\s*\-+\s*([\d\.\s\-E]+)',
+                str_operation=str_to_array, convert=False),
+            Quantity(
+                'lattice_vectors',
+                r'direct lattice vectors\s*reciprocal lattice vectors\s*'
+                r'(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)'
+                r'(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)'
+                r'(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)',
+                str_operation=str_to_array, convert=False),
+            Quantity(
+                'converged',
+                r'aborting loop because (EDIFF is reached)', repeats=False,
+                dtype=str, convert=False),
+            Quantity(
+                'fermi_energy', r'E\-fermi :\s*([\d\.]+)', dtype=str, repeats=False),
+            Quantity(
+                'eigenvalues',
+                r'band No\.\s*band energies\s*occupation\s*([\d\.\s\-]+?)(?:k\-point|spin|\-{10})',
+                repeats=True, dtype=float),
+            Quantity(
+                'convergence',
+                r'(aborting loop because EDIFF is reached)')]
 
-        self._quantities.append(Quantity(
-            'header',
-            r'vasp\.([\d\.]+)\s*(\w+)\s*[\s\S]+?\)\s*(\w+)\s*'
-            r'executed on\s*(\w+)\s*date\s*([\d\.]+)\s*([\d\:]+)\s*(\w+)',
-            repeats=False, str_operation=str_to_header, convert=False))
-
-        self._quantities.append(Quantity(
-            'parameters', r'Startparameter for this run:([\s\S]+?)\-{100}',
-            str_operation=get_key_values, repeats=False, convert=False))
-
-        self._quantities.append(Quantity(
-            'ions_per_type', r'ions per type =\s*([ \d]+)', dtype=int, repeats=False))
-
-        self._quantities.append(Quantity(
-            'species', r'TITEL\s*=\s*(\w+) ([A-Z][a-z]*)', dtype=str, repeats=True))
-
-        self._quantities.append(Quantity(
-            'mass_valence', r'POMASS\s*=\s*([\d\.]+);\s*ZVAL\s*=\s*([\d\.]+)\s*mass and valenz',
-            dtype=float, repeats=True
-        ))
-
-        self._quantities.append(Quantity(
-            'kpoints',
-            r'k-points in reciprocal lattice and weights:[\s\S]+?\n([\d\.\s\-]+)',
-            repeats=False, dtype=float))
-
-        self._quantities.append(Quantity(
-            'nbands', r'NBANDS\s*=\s*(\d+)', dtype=int, repeats=False))
+        self._quantities = [
+            Quantity(
+                'calculation',
+                r'(\-\-\s*Iteration\s*\d+\(\s*1\s*\)\s*[\s\S]+?)'
+                r'((?:FREE ENERGIE OF THE ION\-ELECTRON SYSTEM \(eV\)[\s\S]+?\-{100})|\Z)',
+                repeats=True, sub_parser=TextParser(quantities=calculation_quantities)),
+            Quantity(
+                'header',
+                r'vasp\.([\d\.]+)\s*(\w+)\s*[\s\S]+?\)\s*(\w+)\s*'
+                r'executed on\s*(\w+)\s*date\s*([\d\.]+)\s*([\d\:]+)\s*(\w+)',
+                repeats=False, str_operation=str_to_header, convert=False),
+            Quantity(
+                'parameters', r'Startparameter for this run:([\s\S]+?)\-{100}',
+                str_operation=get_key_values, repeats=False, convert=False),
+            Quantity(
+                'ions_per_type', r'ions per type =\s*([ \d]+)', dtype=int, repeats=False),
+            Quantity(
+                'species', r'TITEL\s*=\s*(\w+) ([A-Z][a-z]*)', dtype=str, repeats=True),
+            Quantity(
+                'mass_valence', r'POMASS\s*=\s*([\d\.]+);\s*ZVAL\s*=\s*([\d\.]+)\s*mass and valenz',
+                dtype=float, repeats=True),
+            Quantity(
+                'kpoints',
+                r'k-points in reciprocal lattice and weights:[\s\S]+?\n([\d\.\s\-]+)',
+                repeats=False, dtype=float),
+            Quantity(
+                'nbands', r'NBANDS\s*=\s*(\d+)', dtype=int, repeats=False),
+            Quantity(
+                'lattice_vectors',
+                r'direct lattice vectors\s*reciprocal lattice vectors\s*'
+                r'(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)'
+                r'(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)'
+                r'(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)(\-?\d+\.\d+\s*)',
+                str_operation=str_to_array, convert=False),
+            Quantity(
+                'positions',
+                r'ion\s*position\s*nearest neighbor table([\s\S]+?)LATTYP',
+                str_operation=str_to_positions, convert=False),
+            # alternative format
+            Quantity(
+                'positions',
+                r'position of ions in cartesian coordinates\s*\(Angst\):([\s\S]+?)\n *\n',
+                str_operation=str_to_positions, convert=False)]
 
 
 class OutcarContentParser(ContentParser):
@@ -411,6 +434,7 @@ class OutcarContentParser(ContentParser):
             ions = self.parser.get('ions_per_type', [])
             species = self.parser.get('species', [])
             ions = [ions] if isinstance(ions, int) else ions
+            ions = [int(i) for i in ions]
             mass_valence = self.parser.get('mass_valence', [])
             if len(ions) != len(species):
                 # get it from POSCAR
@@ -459,10 +483,16 @@ class OutcarContentParser(ContentParser):
         selective = None
         nose = None
 
+        if cell is None:
+            # get it from initialization
+            cell = self.parser.get('lattice_vectors', [None])[0]
+        if positions is None:
+            positions = self.parser.get('positions', None)
+
         if positions is not None:
-            positions = pint.Quantity(positions, 'angstrom')
+            positions = positions * ureg.angstrom
         if cell is not None:
-            cell = pint.Quantity(cell, 'angstrom')
+            cell = cell * ureg.angstrom
 
         return dict(cell=cell, positions=positions, selective=selective, nose=nose)
 
@@ -609,6 +639,10 @@ class OutcarContentParser(ContentParser):
 
         return dos, fields
 
+    def is_converged(self, n_calc):
+        return self.parser.get('calculation', [{}] * (n_calc + 1))[n_calc].get(
+            'convergence') is not None
+
 
 class RunXmlContentHandler(ContentHandler):
     def __init__(self):
@@ -841,7 +875,7 @@ class RunContentParser(ContentParser):
                 self._kpoints_info['divisions'] = divisions['divisions']
             volumeweight = self._get_key_values('/modeling[0]/kpoints[0]/generation[0]/i[@name="volumeweight"]')
             if volumeweight:
-                volumeweight = pint.Quantity(volumeweight['volumeweight'], 'angstrom ** 3').to('m**3')
+                volumeweight = (volumeweight['volumeweight'] * ureg.angstrom ** 3).to('m**3')
                 # TODO set propert unit in metainfo
                 self._kpoints_info['x_vasp_tetrahedron_volume'] = volumeweight.magnitude
             points = self._get_key_values(
@@ -933,9 +967,9 @@ class RunContentParser(ContentParser):
             f'{structure}/nose/v', array=True).get('v', None)
 
         if positions is not None:
-            positions = pint.Quantity(np.dot(positions, cell), 'angstrom')
+            positions = np.dot(positions, cell) * ureg.angstrom
         if cell is not None:
-            cell = pint.Quantity(cell, 'angstrom')
+            cell = cell * ureg.angstrom
 
         return dict(cell=cell, positions=positions, selective=selective, nose=nose)
 
@@ -1046,7 +1080,7 @@ class VASPParser(FairdiParser):
                 r'?\s*<modeling>'
                 r'?\s*<generator>'
                 r'?\s*<i name="program" type="string">\s*vasp\s*</i>'
-                r'?|^\svasp[\.\d]+.+?\s*\(build'),
+                r'?|^\svasp[\.\d]+.+?\s*(?:\(build|complex)'),
             supported_compressions=['gz', 'bz2', 'xz'], mainfile_alternative=True)
 
         self._metainfo_env = m_env
@@ -1074,8 +1108,8 @@ class VASPParser(FairdiParser):
         prec = 1.3 if 'acc' in self.parser.incar.get('PREC', '') else 1.0
         sec_basis_set_cell_dependent = self.archive.section_run[-1].m_create(
             BasisSetCellDependent)
-        sec_basis_set_cell_dependent.basis_set_planewave_cutoff = pint.Quantity(
-            self.parser.incar.get('ENMAX', self.parser.incar.get('ENCUT', 0.0)) * prec, 'eV')
+        sec_basis_set_cell_dependent.basis_set_planewave_cutoff = self.parser.incar.get(
+            'ENMAX', self.parser.incar.get('ENCUT', 0.0)) * prec * ureg.eV
 
         sec_method_basis_set = sec_method.m_create(MethodBasisSet)
         sec_method_basis_set.mapping_section_method_basis_set_cell_associated = sec_basis_set_cell_dependent
@@ -1117,8 +1151,7 @@ class VASPParser(FairdiParser):
             atom_label = '%s%d' % (
                 element[i], atom_counts[element[i]]) if atom_counts[element[i]] > 0 else element[i]
             sec_method_atom_kind.method_atom_kind_label = str(atom_label)
-            sec_method_atom_kind.method_atom_kind_mass = pint.Quantity(
-                atomtypes.get('mass', [1] * (i + 1))[i], 'amu')
+            sec_method_atom_kind.method_atom_kind_mass = atomtypes.get('mass', [1] * (i + 1))[i] * ureg.amu
             sec_method_atom_kind.method_atom_kind_explicit_electrons = atomtypes.get(
                 'valence', [0] * (i + 1))[i]
             pseudopotential = atomtypes.get('pseudopotential')[i]
@@ -1137,6 +1170,21 @@ class VASPParser(FairdiParser):
                 sec_xc_functional = sec_method.m_create(XCFunctionals)
                 sec_xc_functional.XC_functional_name = xc_functional
 
+        # convergence thresholds
+        tolerance = self.parser.incar.get('EDIFF')
+        if tolerance is not None:
+            sec_method.scf_threshold_energy_change = tolerance * ureg.eV
+
+    def parse_sampling_method(self):
+        sec_sampling_method = self.archive.section_run[-1].m_create(SamplingMethod)
+
+        tolerance = self.parser.incar.get('EDIFFG')
+        if tolerance is not None:
+            if tolerance > 0:
+                sec_sampling_method.geometry_optimization_energy_change = tolerance * ureg.eV
+            else:
+                sec_sampling_method.geometry_optimization_threshold_force = abs(tolerance) * ureg.eV / ureg.angstrom
+
     def parse_configurations(self):
         sec_run = self.archive.section_run[-1]
 
@@ -1181,7 +1229,7 @@ class VASPParser(FairdiParser):
                 if val is None or metainfo_key is None:
                     continue
 
-                val = pint.Quantity(val, 'eV')
+                val = val * ureg.eV
 
                 try:
                     setattr(section, '%s%s' % (metainfo_key, ext), val)
@@ -1210,8 +1258,8 @@ class VASPParser(FairdiParser):
                 valence_max.append(np.amin(eigs[i]) - 1.0 if not occupied else max(occupied))
                 unoccupied = [eigs[i, o[0], o[1]] for o in np.argwhere(occs[i] < 0.5)]
                 conduction_min.append(np.amin(eigs[i]) - 1.0 if not unoccupied else min(unoccupied))
-            sec_scc.energy_reference_highest_occupied = pint.Quantity(valence_max, 'eV')
-            sec_scc.energy_reference_lowest_unoccupied = pint.Quantity(conduction_min, 'eV')
+            sec_scc.energy_reference_highest_occupied = valence_max * ureg.eV
+            sec_scc.energy_reference_lowest_unoccupied = conduction_min * ureg.eV
 
             if self.parser.kpoints_info.get('x_vasp_k_points_generation_method', None) == 'listgenerated':
                 # I removed normalization since imho it should be done by normalizer
@@ -1230,13 +1278,13 @@ class VASPParser(FairdiParser):
                 occs = np.transpose(occs, axes=(1, 0, 2, 3))
                 for n in range(n_segments):
                     sec_k_band_segment = sec_k_band.m_create(KBandSegment)
-                    sec_k_band_segment.band_energies = pint.Quantity(eigs[n], 'eV')
+                    sec_k_band_segment.band_energies = eigs[n] * ureg.eV
                     sec_k_band_segment.band_occupations = occs[n]
                     sec_k_band_segment.band_k_points = kpoints[n]
                     sec_k_band_segment.band_segm_start_end = np.asarray(
                         [kpoints[n, 0], kpoints[n, divisions - 1]])
             else:
-                sec_eigenvalues.eigenvalues_values = pint.Quantity(eigs, 'eV')
+                sec_eigenvalues.eigenvalues_values = eigs * ureg.eV
                 sec_eigenvalues.eigenvalues_occupation = occs
 
         def parse_dos(n_calc):
@@ -1253,17 +1301,17 @@ class VASPParser(FairdiParser):
             if values is not None:
                 sec_scc = sec_run.section_single_configuration_calculation[-1]
                 sec_dos = sec_scc.m_create(Dos)
-                sec_dos.dos_energies = pint.Quantity(energies, 'eV')
+                sec_dos.dos_energies = energies * ureg.eV
 
-                sec_dos.dos_values = pint.Quantity(values, '1/eV').to('1/joule').magnitude
+                sec_dos.dos_values = (values / ureg.eV).to('1/joule').magnitude
                 sec_dos.dos_integrated_values = integrated
 
-                sec_dos.energy_reference_fermi = pint.Quantity([e_fermi] * self.parser.ispin, 'eV')
+                sec_dos.energy_reference_fermi = ([e_fermi] * self.parser.ispin) * ureg.eV
 
                 # partial dos
                 dos, fields = self.parser.get_partial_dos(n_calc)
                 if dos is not None:
-                    sec_dos.dos_values_lm = pint.Quantity(dos, '1/eV').to('1/joule').magnitude
+                    sec_dos.dos_values_lm = (dos / ureg.eV).to('1/joule').magnitude
                     sec_dos.dos_lm = [lm_converter.get(field, [-1, -1]) for field in fields]
                     sec_dos.dos_m_kind = 'polynomial'
 
@@ -1277,13 +1325,13 @@ class VASPParser(FairdiParser):
             forces, stress = self.parser.get_forces_stress(n)
             if forces is not None:
                 try:
-                    sec_scc.atom_forces = pint.Quantity(forces, 'eV/angstrom')
+                    sec_scc.atom_forces = forces * ureg.eV / ureg.angstrom
                 except Exception:
                     self.logger.error('Error parsing forces.')
             if stress is not None:
                 try:
                     # TODO verify if stress unit in xml is also kbar
-                    sec_scc.stress_tensor = pint.Quantity(stress, 'kbar')
+                    sec_scc.stress_tensor = stress * ureg.kbar
                 except Exception:
                     self.logger.error('Error parsing stress.')
 
@@ -1298,6 +1346,14 @@ class VASPParser(FairdiParser):
             # dos
             parse_dos(n)
 
+            # convergence
+            converged = self.parser.is_converged(n)
+            if converged:
+                sec_scc.single_configuration_calculation_converged = converged
+
+        if self.parser.n_calculations == 0:
+            self.logger.warn('No calculation was parsed.')
+
     def parse(self, filepath, archive, logger):
         self.filepath = filepath
         self.archive = archive
@@ -1328,4 +1384,6 @@ class VASPParser(FairdiParser):
 
         self.parse_method()
 
+        self.parse_sampling_method()
+
         self.parse_configurations()
