@@ -85,7 +85,8 @@ def __run_parallel(
 
 
 def __run_processing(
-        uploads, parallel: int, process, label: str, reprocess_running: bool = False):
+        uploads, parallel: int, process, label: str, reprocess_running: bool = False,
+        wait_for_tasks: bool = True, reset_first: bool = False):
 
     def run_process(upload, logger):
         logger.info(
@@ -98,16 +99,26 @@ def __run_processing(
                 current_process=upload.current_process,
                 current_task=upload.current_task, upload_id=upload.upload_id)
             return False
-        else:
+
+        if reset_first:
             upload.reset(force=True)
-            process(upload)
+        elif upload.process_running:
+            tasks_status = upload.tasks_status
+            if tasks_status == proc.RUNNING:
+                tasks_status = proc.FAILURE
+            upload.reset(force=True, tasks_status=tasks_status)
+
+        process(upload)
+        if wait_for_tasks:
             upload.block_until_complete(interval=.5)
+        else:
+            upload.block_until_process_complete(interval=.5)
 
-            if upload.tasks_status == proc.FAILURE:
-                logger.info('%s with failure' % label, upload_id=upload.upload_id)
+        if upload.tasks_status == proc.FAILURE:
+            logger.info('%s with failure' % label, upload_id=upload.upload_id)
 
-            logger.info('%s complete' % label, upload_id=upload.upload_id)
-            return True
+        logger.info('%s complete' % label, upload_id=upload.upload_id)
+        return True
 
     __run_parallel(uploads, parallel=parallel, callable=run_process, label=label)
 
@@ -198,7 +209,9 @@ def lift_embargo(dry, parallel):
                     search.index_all(entries)
 
     if not dry:
-        __run_processing(uploads_to_repack, parallel, lambda upload: upload.re_pack(), 're-packing')
+        __run_processing(
+            uploads_to_repack, parallel, lambda upload: upload.re_pack(), 're-packing',
+            wait_for_tasks=False)
 
 
 @admin.command()
