@@ -80,7 +80,6 @@ def metainfo_undecorated():
     import nomad.datamodel.ems
     import nomad.datamodel.optimade
     import nomad.datamodel.encyclopedia
-    from nomad.parsing import LegacyParser
     nomad.metainfo.metainfo.m_package.__init_metainfo__()
     nomad.datamodel.datamodel.m_package.__init_metainfo__()
     nomad.datamodel.dft.m_package.__init_metainfo__()  # pylint: disable=no-member
@@ -88,11 +87,10 @@ def metainfo_undecorated():
     nomad.datamodel.optimade.m_package.__init_metainfo__()  # pylint: disable=no-member
     nomad.datamodel.encyclopedia.m_package.__init_metainfo__()
 
-    # Ensure all parser metainfo is loaded
-    from nomad.parsing.parsers import parsers
-    for parser in parsers:
-        if isinstance(parser, LegacyParser):
-            _ = parser.metainfo_env
+    # TODO similar to before, due to lazyloading, we need to explicily access parsers
+    # to actually import all parsers and indirectly all metainfo packages
+    from nomad.parsing import parsers
+    parsers.parsers
 
     export = Environment()
     for package in Package.registry.values():
@@ -137,14 +135,12 @@ def parser_metadata():
     import json
     import yaml
 
-    from nomad.parsing import LegacyParser, FairdiParser
+    from nomad.parsing import Parser
     from nomad.parsing.parsers import parser_dict
 
     parsers_metadata = {}
     for parser in parser_dict.values():
-        if isinstance(parser, LegacyParser):
-            parser_class = parser.parser_class
-        elif isinstance(parser, FairdiParser):
+        if isinstance(parser, Parser):
             parser_class = parser.__class__
         else:
             continue
