@@ -37,6 +37,7 @@ Depending on the configuration all logs will also be send to a central logstash.
 .. autofunc::nomad.utils.lnr
 '''
 
+from typing import cast, Any
 import logging
 import structlog
 from structlog.processors import StackInfoRenderer, format_exc_info, TimeStamper, JSONRenderer
@@ -46,7 +47,7 @@ from contextlib import contextmanager
 import json
 import re
 
-from nomad import config
+from nomad import config, utils
 
 
 def sanitize_logevent(event: str) -> str:
@@ -86,9 +87,16 @@ class LogstashHandler(logstash.TCPLogstashHandler):
 
     legacy_logger = None
 
+    def __init__(self):
+        super().__init__(
+            config.logstash.host,
+            config.logstash.tcp_port, version=1)
+
     def filter(self, record):
-        if record.name == 'gunicorn.access' and 'alive' in record.args.get('r', ''):
-            return False
+        if record.name == 'uvicorn.access':
+            http_access_path = record.args[2]
+            if 'alive' in http_access_path or 'gui/index.html' in http_access_path:
+                return False
 
         if super().filter(record):
             is_structlog = False
@@ -111,20 +119,6 @@ class LogstashHandler(logstash.TCPLogstashHandler):
         return False
 
 
-_gunicorn_pattern_parts = [
-    r'(?P<host>\S+)',  # host %h
-    r'\S+',  # indent %l (unused)
-    r'(?P<user>\S+)',  # user %u
-    r'\[(?P<time>.+)\]',  # time %t
-    r'"(?P<request>.+)"',  # request "%r"
-    r'(?P<status>[0-9]+)',  # status %>s
-    r'(?P<size>\S+)',  # size %b (careful, can be '-')
-    r'"(?P<referer>.*)"',  # referer "%{Referer}i"
-    r'"(?P<agent>.*)"',  # user agent "%{User-agent}i"
-]
-_gunicorn_pattern = re.compile(r'\s+'.join(_gunicorn_pattern_parts) + r'\s*\Z')
-
-
 class LogstashFormatter(logstash.formatter.LogstashFormatterBase):
 
     def format(self, record):
@@ -149,7 +143,10 @@ class LogstashFormatter(logstash.formatter.LogstashFormatterBase):
 
             # Nomad specific
             'nomad.service': config.meta.service,
-            'nomad.release': config.meta.release
+            'nomad.release': config.meta.release,
+            'nomad.version': config.meta.version,
+            'nomad.commit': config.meta.commit,
+            'nomad.deployment': config.meta.deployment
         }
 
         if record.name.startswith('nomad'):
@@ -157,7 +154,12 @@ class LogstashFormatter(logstash.formatter.LogstashFormatterBase):
                 if key in ('event', 'stack_info', 'id', 'timestamp'):
                     continue
                 elif key == 'exception':
+                    exception_trace = value.strip('\n')
                     message['digest'] = str(value)[-256:]
+                    # exclude the last line, which is the exception message and might
+                    # vary for different instances of the same exception
+                    message['exception_hash'] = utils.hash(
+                        exception_trace[:exception_trace.rfind('\n')])
                 elif key in ['upload_id', 'calc_id', 'mainfile']:
                     key = 'nomad.%s' % key
                 else:
@@ -167,29 +169,32 @@ class LogstashFormatter(logstash.formatter.LogstashFormatterBase):
         else:
             message.update(structlog)
 
-        # Handle gunicorn access events
-        if record.name == 'gunicorn.access':
-            gunicorn_message = structlog['event']
-            gunicorn_record = _gunicorn_pattern.match(gunicorn_message).groupdict()
-
-            if gunicorn_record['user'] == '-':
-                gunicorn_record['user'] = None
-
-            gunicorn_record['status'] = int(gunicorn_record['status'])
-
-            if gunicorn_record['size'] == '-':
-                gunicorn_record['size'] = 0
-            else:
-                gunicorn_record['size'] = int(gunicorn_record['size'])
-
-            if gunicorn_record['referer'] == '-':
-                gunicorn_record['referer'] = None
-
-            message.update({'gunicorn.%s' % key: value for key, value in gunicorn_record.items()})
-            message['event'] = gunicorn_record['request']
-
-        # Add extra fields
-        message.update(self.get_extra_fields(record))
+        # Handle uvicorn access events
+        if record.name == 'uvicorn.access':
+            status_code = getattr(record, 'status_code', None)
+            if status_code is not None:
+                message['uvicorn.status_code'] = status_code
+            scope = getattr(record, 'scope', None)
+            if scope is not None:
+                message['uvicorn.method'] = scope['method']
+                message['uvicorn.path'] = scope['path']
+                message['uvicorn.query_string'] = scope['query_string'].decode()
+                message['uvicorn.headers'] = {
+                    key.decode(): value.decode() for key, value in scope['headers']}
+            args = getattr(record, 'args', None)
+            if args is not None and len(args) == 5:
+                _, method, path_w_query, _, status_code = args
+                path_w_query_components = path_w_query.split('?', 1)
+                path = path_w_query_components[0]
+                if len(path_w_query_components) == 2:
+                    query_string = path_w_query_components[1]
+                    message['uvicorn.query_string'] = query_string
+                message['uvicorn.method'] = method
+                message['uvicorn.path'] = path
+                message['uvicorn.status_code'] = status_code
+        else:
+            # Add extra fields
+            message.update(self.get_extra_fields(record))
 
         # If exception, add debug info
         if record.exc_info:
@@ -239,9 +244,7 @@ def add_logstash_handler(logger):
         if isinstance(handler, LogstashHandler)), None)
 
     if logstash_handler is None:
-        logstash_handler = LogstashHandler(
-            config.logstash.host,
-            config.logstash.tcp_port, version=1)
+        logstash_handler = LogstashHandler()
         logstash_handler.formatter = LogstashFormatter(tags=['nomad', config.meta.release])
         logstash_handler.setLevel(config.logstash.level)
         logger.addHandler(logstash_handler)
@@ -277,7 +280,7 @@ def logger_factory(*args):
 
 
 structlog.configure(
-    processors=log_processors,
+    processors=cast(Any, log_processors),
     logger_factory=logger_factory,
     wrapper_class=structlog.stdlib.BoundLogger)
 
@@ -311,6 +314,5 @@ if config.logstash.enabled:
 # configure log levels
 for logger in [
         'elasticsearch',
-        # 'celery.app.trace', 'celery.worker.strategy',
         'urllib3.connectionpool', 'bravado', 'bravado_core', 'swagger_spec_validator']:
     logging.getLogger(logger).setLevel(logging.WARNING)
